/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package sikd.ikonsol.ejb.session;

import java.util.List;
import javax.ejb.Remote;
import sikd.ikonsol.model.Informasi;

/**
 *
 * @author Imam Bhoim
 */
@Remote
public interface InformasiEjbHome {

    public List<Informasi> findAllInfoApp();
    public List<Informasi> findAllDokApp();
    public List<Informasi> findAllPeraturanApp();

    public Informasi findByIDOverview(int id);
    public Informasi findByIDDisclaimer(int id);
    public Informasi findByIDInfoApp(int id);
    public Informasi findByIDDokApp(int id);
    public Informasi findByIDPeraturanApp(int id);
    
    public Informasi findByIDKontak(int id);

    public Informasi createNewInfoApp();
    public Informasi saveInfoApp(Informasi obj);
    public Informasi updateInfoApp(Informasi obj);
    public void deleteInfoApp(int id);

    public Informasi createNewDokApp();
    public Informasi saveDokApp(Informasi obj);
    public Informasi updateDokApp(Informasi obj);
    public void deleteDokApp(int id);

    public Informasi createNewPeraturanApp();
    public Informasi savePeraturanApp(Informasi obj);
    public Informasi updatePeraturanApp(Informasi obj);
    public void deletePeraturanApp(int id);
    
    public Informasi updateOverviewApp(Informasi obj);
     public Informasi updateDisclaimerApp(Informasi obj);
     
       public Informasi updateKontak(Informasi obj);
     
     public Informasi uploadFileDok(Informasi obj);
       public Informasi uploadFilePer(Informasi obj);

}
